@@ -51,6 +51,9 @@ def superindex(it,value):
         if it[i]==value:
             res+=[i]
     return res
+class RoExitStringError(Exception):
+    def __init__(self,*argv):
+        pass
 class Ro_Error:
     def __init__(self,line,text,string,p=0,lang='RUS'):
         self.lang=lang
@@ -58,7 +61,7 @@ class Ro_Error:
         self.info=text
         self.string=string
         self.out(p)
-        exit(1)
+        raise RoExitStringError('')
     def ie(self): pass
     def out(self,p):
         print(self.stroka(),str(self.line)+':',"\n "+self.string,"\n"+self.pos(p),'\n',self.name()+':',self.info)
@@ -130,11 +133,11 @@ class Robin:
         if lang=="EN":
             self.new_object("True",'bool',True,None,None)
             self.new_object("False",'bool',False,None,None)
-            print('Robin 0.5.0 open sourse edition.')
+            print('Robin 0.5.2 open sourse edition.')
         if lang=='RUS':
             self.new_object("Истина",'bool',True,None,None)
             self.new_object("Ложь",'bool',False,None,None)
-            print('Робин 0.5.0 открытое издание.')
+            print('Робин 0.5.2 открытое издание.')
     def load(self,ert):
         self.eexece(ert)
     def eexece(self,code):
@@ -180,8 +183,9 @@ class Robin:
             if ' ' in string:
                 oper=string.split()[0]
                 if oper=='строка' and lang=='RUS' or oper=='goto' and lang=='EN':
+                    #if True:
                     try:
-                        i=eval(boolexec(string.split()[1]))-2
+                        i=eval(self.boolexex(string.split()[1],i+1,string))-2
                     except:
                         if lang=="RUS": Ro_SintaxError(i+1,'Должно быть число',string)
                         if lang=="EN": Ro_SintaxError(i+1,'Must be a number',string,lang='EN')
@@ -191,9 +195,12 @@ class Robin:
                         print(eval(self.boolexex(string.split()[1],i+1,string)))
                     except: Ro_SintaxError(i+1,'',string,lang=lang)
                 if oper=='чисввод' and lang=='RUS' or oper=='intentry' and lang=='EN':
+                    #if True:
                     try:
                         self.new_object(string.split()[1],'int',int(input()),i+1,string)
-                    except: Ro_SintaxError(i+1,'',string,lang=self.lang)
+                    except ValueError:
+                        if lang=='EN': Ro_SintaxError(i+1,'Must be input a number!',string,lang=self.lang)
+                        if lang=='RUS': Ro_SintaxError(i+1,'Введено не число!',string,lang=self.lang)
                 if oper=='если' and lang=='RUS' or oper=='if' and lang=='EN':
                     n=string.index(':')
                     s1=string.index('(')
@@ -223,7 +230,7 @@ class Robin:
                                     es=eval(self.boolexex(strlist[1],i+1,strin))
                                     self.new_object(strlist[0],'int',es,i+1,strin)
                                 except: Ro_SintaxError(i+1,'',strin,lang=lang)
-                    except:
+                    except :
                         Ro_SintaxError(i+1,'',string,lang=lang)
                 i+=1
                 continue
@@ -252,4 +259,4 @@ if(__name__=="__main__"):
     inter=Robin(lang=input('Language\Язык (EN,RUS)_ '))
     while True:
         try: inter.load(input('>>> '))
-        except SystemExit: pass
+        except RoExitStringError: pass
